@@ -1,6 +1,6 @@
 /* The IGEN simulator generator for GDB, the GNU Debugger.
 
-   Copyright 2002-2022 Free Software Foundation, Inc.
+   Copyright 2002-2023 Free Software Foundation, Inc.
 
    Contributed by Andrew Cagney.
 
@@ -45,8 +45,8 @@ struct _lf
 
 
 lf *
-lf_open (char *name,
-	 char *real_name,
+lf_open (const char *name,
+	 const char *real_name,
 	 lf_file_references references,
 	 lf_file_type type, const char *program)
 {
@@ -205,7 +205,7 @@ lf_printf (lf *file, const char *fmt, ...)
 
 
 int
-lf_print__line_ref (lf *file, line_ref *line)
+lf_print__line_ref (lf *file, const line_ref *line)
 {
   return lf_print__external_ref (file, line->line_nr, line->file_name);
 }
